@@ -25,6 +25,27 @@ function signedLiteral (num) {
     };
 }
 
+function rpush (a) {
+    return {
+        type: Syntax.ExpressionStatement,
+        expression: {
+            type: Syntax.CallExpression,
+            callee: {
+                type: Syntax.MemberExpression,
+                computed: false,
+                object: {
+                    type: Syntax.ThisExpression
+                },
+                property: {
+                    type: Syntax.Identifier,
+                    name: 'rpush'
+                }
+            },
+            arguments: a
+        }
+    };
+}
+
 function dpush (e) {
     return {
         type: Syntax.ExpressionStatement,
@@ -66,6 +87,24 @@ function dpop () {
     };
 }
 
+function rpop () {
+    return {
+        type: Syntax.CallExpression,
+        callee: {
+            type: Syntax.MemberExpression,
+            computed: false,
+            object: {
+                type: Syntax.ThisExpression
+            },
+            property: {
+                type: Syntax.Identifier,
+                name: 'rpop'
+            }
+        },
+        arguments: []
+    };
+}
+
 function notdpop () {
     return {
         type: Syntax.UnaryExpression,
@@ -132,6 +171,8 @@ function program (body) {
 module.exports = {
     dpush: dpush,
     dpop: dpop,
+    rpush: rpush,
+    rpop: rpop,
     notdpop: notdpop,
     callword: callword,
     program: program
