@@ -23,6 +23,16 @@ function main (cxt) {
         }, this);
     }, cxt);
 
+// CODE
+def('code', function () {
+    var w = this.io.word('\\s');
+    var source = this.io.parse('#');
+    def(w, source, this);
+}, cxt);
+
+def('end-code', function () {
+}, cxt);
+
 // : DOES> ??? ; IMMEDIATE
 // : POSTPONE ' LITERAL ['] , LITERAL ; IMMEDIATE \ : POSTPONE ' , ;
 
@@ -63,7 +73,7 @@ function main (cxt) {
             }
             return e.name;
         }, this);
-        console.log(list.join(' '));
+        console.log(list.join(' ') + '\n');
     }, cxt);
 
 /*
@@ -79,12 +89,12 @@ function main (cxt) {
 
 */
     def('see', function () {
-        var w = this.io.word('\\s');
+        var w = this.io.word('\\s').toLowerCase();
         // var list = this.L.map(function (e) {
         //     return colors.green(e.name) + ': ' + this[this.O[e.name].index];
         // }, this);
         // console.log(list.join('\n'));
-        console.log(colors.green(w) + ': ' + this[this.O[w].index]);
+        console.log(colors.green(w) + ': ' + this[this.O[w].index] + '\n');
     }, cxt);
 
 // 6.1.0070 ' “tick” (CORE)
