@@ -35,6 +35,19 @@ function main (cxt) {
 // 'c!':   null,
 // 'c,':   null,
 // 'c@':   null,
+
+// 6.1.0130 +! “plus-store” (CORE)
+// ( n|u a-addr -- )
+// Add n|u to the single-cell number at a-addr.
+
+    def ('+!', function () {
+        var t = this.dpop();
+        var n = this.dpop();
+        var tmp = this.MEMi32[t >> 2];
+        tmp = (tmp + n) | 0;
+        this.MEMi32[t >> 2] = tmp;
+    }, cxt);
+
     def('@', function () {
         var t = this.dpop();
         this.dpush(this.MEMi32[t >> 2]); // TODO 32-bit read?
